==> malisiscore-1.7.10-0.12.5-sources.jar: net/malisis/core/client/gui/element/XResizableGuiShape.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Ordinastie
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.malisis.core.client.gui.element;

/**
 * @author Ordinastie
 *
 */
public class XResizableGuiShape extends GuiShape
{
	protected int sideWidth;

	public XResizableGuiShape(int sideWidth)
	{
		super(3);
		this.sideWidth = sideWidth;
		storeState();
	}

	public XResizableGuiShape()
	{
		this(5);
	}

	@Override
	public void setSize(int w, int h)
	{
		w = Math.max(w - 2 * sideWidth, 0);

		faces[0].factor(sideWidth, h, 0);
		faces[1].factor(w, h, 0);
		faces[2].factor(sideWidth, h, 0);

		faces[1].translate(sideWidth, 0, 0);
		faces[2].translate(sideWidth + w, 0, 0);
	}

	@Override
	public void scale(float x, float y)
	{}
}

==> malisiscore-1.10.2-4.2.3-sources.jar: net/malisis/core/client/gui/element/XResizableGuiShape.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Ordinastie
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.malisis.core.client.gui.element;

/**
 * @author Ordinastie
 *
 */
public class XResizableGuiShape extends GuiShape
{
	protected int sideWidth;

	public XResizableGuiShape(int sideWidth)
	{
		super(3);
		this.sideWidth = sideWidth;
		storeState();
	}

	public XResizableGuiShape()
	{
		this(5);
	}

	@Override
	public void setSize(int w, int h)
	{
		w = Math.max(w - 2 * sideWidth, 0);

		faces[0].scale(sideWidth, h, 0);
		faces[1].scale(w, h, 0);
		faces[2].scale(sideWidth, h, 0);

		faces[1].translate(sideWidth, 0, 0);
		faces[2].translate(sideWidth + w, 0, 0);
	}

	@Override
	public void scale(float x, float y)
	{}
}
